@@ -1,11 +1,16 @@
 # -*- coding: utf-8 -*-
 import re
 import sys
-from typing import Iterable, Iterator, Optional, Pattern, Sequence
+from typing import Iterable, Iterator, Optional, Pattern, Sequence, Tuple
 
 import grpc
 
-from esdbclient.esdbapi import Streams
+from esdbclient.esdbapi import (
+    Streams,
+    SubscriptionReadRequest,
+    SubscriptionReadResponse,
+    Subscriptions,
+)
 from esdbclient.events import NewEvent, RecordedEvent
 from esdbclient.exceptions import StreamNotFound
 
@@ -21,6 +26,7 @@ class EsdbClient:
         self.uri = uri
         self.channel = grpc.insecure_channel(self.uri)
         self.streams = Streams(self.channel)
+        self.subscriptions = Subscriptions(self.channel)
 
     def append_events(
         self,
@@ -142,6 +148,18 @@ class EsdbClient:
             filter_include=filter_include,
         )
 
+    def create_subscription(
+        self, group_name: str, from_end: bool = False, position: Optional[int] = None
+    ) -> None:
+        self.subscriptions.create(
+            group_name=group_name, from_end=from_end, commit_position=position
+        )
+
+    def read_subscription(
+        self, group_name: str
+    ) -> Tuple[SubscriptionReadRequest, SubscriptionReadResponse]:
+        return self.subscriptions.read(group_name=group_name)
+
 
 class CatchupSubscription:
     """
@@ -169,9 +187,6 @@ class CatchupSubscription:
 
     def __iter__(self) -> Iterator[RecordedEvent]:
         for event in self.event_generator:
-            if event.type == "" and event.stream_name == "":
-                # Todo: What is this? occurs several times (has commit_position=0)
-                continue
             if self.filter_regex is None:
                 yield event
             elif re.match(self.filter_regex, event.type):
