@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from dataclasses import dataclass
+from uuid import UUID
 
 
 @dataclass(frozen=True)
@@ -19,6 +20,7 @@ class RecordedEvent(NewEvent):
     Encapsulates event data that has been recorded in EventStoreDB.
     """
 
+    id: UUID
     stream_name: str
     stream_position: int
     commit_position: int
